==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/proxy/frontend/spi/src/main/java/org/apache/shardingsphere/proxy/frontend/authentication/AuthenticationEngine.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.proxy.frontend.authentication;

import io.netty.channel.ChannelHandlerContext;
import org.apache.shardingsphere.authentication.result.AuthenticationResult;
import org.apache.shardingsphere.db.protocol.payload.PacketPayload;

/**
 * Authentication engine.
 */
public interface AuthenticationEngine {
    
    /**
     * Handshake.
     *
     * @param context channel handler context
     * @return connection ID
     */
    int handshake(ChannelHandlerContext context);
    
    /**
     * Authenticate.
     *
     * @param context channel handler context
     * @param payload packet payload
     * @return authentication result
     */
    AuthenticationResult authenticate(ChannelHandlerContext context, PacketPayload payload);
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/proxy/frontend/spi/src/main/java/org/apache/shardingsphere/proxy/frontend/authentication/AuthenticationEngine.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.proxy.frontend.authentication;

import io.netty.channel.ChannelHandlerContext;
import org.apache.shardingsphere.authentication.result.AuthenticationResult;
import org.apache.shardingsphere.database.protocol.payload.PacketPayload;

/**
 * Authentication engine.
 */
public interface AuthenticationEngine {
    
    /**
     * Handshake.
     *
     * @param context channel handler context
     * @return connection ID
     */
    int handshake(ChannelHandlerContext context);
    
    /**
     * Authenticate.
     *
     * @param context channel handler context
     * @param payload packet payload
     * @return authentication result
     */
    AuthenticationResult authenticate(ChannelHandlerContext context, PacketPayload payload);
}
